==> istio-model-v1beta1-6.4.0-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.lang.Long;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PeerAuthenticationSpecFluent<A extends PeerAuthenticationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @Deprecated
  public PeerAuthenticationMutualTLS getMtls();
  public PeerAuthenticationMutualTLS buildMtls();
  public A withMtls(PeerAuthenticationMutualTLS mtls);
  public Boolean hasMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtlsLike(PeerAuthenticationMutualTLS item);
  public PeerAuthenticationSpecFluent.MtlsNested<A> editMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtlsLike(PeerAuthenticationMutualTLS item);
  public A addToPortLevelMtls(Long key,PeerAuthenticationMutualTLS value);
  public A addToPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map);
  public A removeFromPortLevelMtls(Long key);
  public A removeFromPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map);
  public Map<Long,PeerAuthenticationMutualTLS> getPortLevelMtls();
  public <K,V>A withPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> portLevelMtls);
  public Boolean hasPortLevelMtls();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface MtlsNested<N> extends Nested<N>,PeerAuthenticationMutualTLSFluent<PeerAuthenticationSpecFluent.MtlsNested<N>>{
    public N and();
    public N endMtls();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<PeerAuthenticationSpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}

==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/security/v1beta1/PeerAuthenticationSpecFluent.java <==
package io.fabric8.istio.api.security.v1beta1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.LinkedHashMap;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelector;
import java.lang.Deprecated;
import java.lang.Long;
import io.fabric8.istio.api.type.v1beta1.WorkloadSelectorFluent;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PeerAuthenticationSpecFluent<A extends PeerAuthenticationSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildMtls instead.
   * @return The buildable object.
   */
  @Deprecated
  public PeerAuthenticationMutualTLS getMtls();
  public PeerAuthenticationMutualTLS buildMtls();
  public A withMtls(PeerAuthenticationMutualTLS mtls);
  public Boolean hasMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> withNewMtlsLike(PeerAuthenticationMutualTLS item);
  public PeerAuthenticationSpecFluent.MtlsNested<A> editMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtls();
  public PeerAuthenticationSpecFluent.MtlsNested<A> editOrNewMtlsLike(PeerAuthenticationMutualTLS item);
  public A addToPortLevelMtls(Long key,PeerAuthenticationMutualTLS value);
  public A addToPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map);
  public A removeFromPortLevelMtls(Long key);
  public A removeFromPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> map);
  public Map<Long,PeerAuthenticationMutualTLS> getPortLevelMtls();
  public <K,V>A withPortLevelMtls(Map<Long,PeerAuthenticationMutualTLS> portLevelMtls);
  public Boolean hasPortLevelMtls();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @Deprecated
  public WorkloadSelector getSelector();
  public WorkloadSelector buildSelector();
  public A withSelector(WorkloadSelector selector);
  public Boolean hasSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewTypeSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> withNewSelectorLike(WorkloadSelector item);
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editTypeSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelector();
  public PeerAuthenticationSpecFluent.TypeSelectorNested<A> editOrNewSelectorLike(WorkloadSelector item);
  public interface MtlsNested<N> extends Nested<N>,PeerAuthenticationMutualTLSFluent<PeerAuthenticationSpecFluent.MtlsNested<N>>{
    public N and();
    public N endMtls();
    
  }
  public interface TypeSelectorNested<N> extends Nested<N>,WorkloadSelectorFluent<PeerAuthenticationSpecFluent.TypeSelectorNested<N>>{
    public N and();
    public N endTypeSelector();
    
  }
  
}
